# ANML

Automatic Machine Learning Outliers Handler library.

## Installation

pip install AnLOF

## Usage

```python
from AnLOF import AnLOF

anlof = AnLOF(
    X_train, X_val, y_train, y_val,
    features ,##features with outliers
    base_model=LinearRegression,
    metric=mean_squared_error,
    higher_is_better=False
)
best_X_train, best_X_val, best_method, performance_df = anlof.forward()


print("Best method:",best_method)
print("Best X_train :", best_X_train.head())
print("Best X_val :", best_X_val.head())    
print(performance_df)


